@@ -1,6 +1,8 @@
 import numpy as np
 from scipy import stats
 from scipy.special import factorial
+from . import helperfunctions as hfns
+from . import distributions as distributions
 
 class LossAggregation:
     """
