@@ -1,6 +1,8 @@
 import numpy as np
 import matplotlib.pyplot as plt
 from scipy.fft import fft, ifft
+from . import helperfunctions as hfns
+from . import distributions as distributions
 
 ## Actual
 class Frequency:
